@@ -5,7 +5,7 @@ import shlex
 import tempfile
 from datetime import datetime
 from itertools import chain, repeat
-from subprocess import run, CalledProcessError
+from subprocess import run, CalledProcessError, PIPE
 from typing import Dict, Any, Iterable
 
 import pytest
@@ -235,7 +235,7 @@ class DbtItem(pytest.Item):
         if cli_vars:
             full_cmd.extend(('--vars', yaml.safe_dump(cli_vars)))
         expect_passes = sequence_item.get('check', True)
-        result = run(full_cmd, check=False, capture_output=True)
+        result = run(full_cmd, check=False, stdout=PIPE, stderr=PIPE)
         print(result.stdout.decode('utf-8'))
         if expect_passes:
             if result.returncode != 0:
@@ -271,18 +271,47 @@ class DbtItem(pytest.Item):
             attributes[name][keypath] = value
         return attributes
 
+    @staticmethod
+    def _get_name(
+        result: Dict[str, Any],
+        nodes: Dict[str, Any]
+    ) -> str:
+        """Given a run result get the unique_id and lookup the name from
+        a dict of nodes mapped to their unique_id.
+        """
+        try:
+            unique_id = result['unique_id']
+        except KeyError as exc:
+            raise DBTException(
+                f'Invalid result, missing required key {exc}'
+            ) from None
+        try:
+            return nodes[unique_id]['name']
+        except KeyError as exc:
+            raise DBTException(
+                f'Invalid node, missing required key {exc}'
+            ) from None
+
     def step_run_results(self, sequence_item, tmpdir):
-        path = os.path.join(tmpdir, 'project', 'target', 'run_results.json')
+        run_results_path = os.path.join(
+            tmpdir, 'project', 'target', 'run_results.json')
+        manifest_path = os.path.join(
+            tmpdir, 'project', 'target', 'manifest.json')
 
         expect_exists = sequence_item.get('exists', True)
 
-        assert expect_exists == os.path.exists(path)
+        assert expect_exists == os.path.exists(run_results_path)
         if not expect_exists:
             return None
 
         try:
-            with open(path) as fp:
-                run_results_data = json.load(fp)
+            with open(
+                run_results_path
+            ) as results_fp, open(
+                manifest_path
+            ) as manifest_fp:
+                run_results_data = json.load(results_fp)
+                manifest_data = json.load(manifest_fp)
         except Exception as exc:
             raise DBTException(
                 f'could not load run_results.json: {exc}'
@@ -293,6 +322,13 @@ class DbtItem(pytest.Item):
             raise DBTException(
                 'Invalid run_results.json - no results'
             ) from None
+        try:
+            nodes = manifest_data['nodes']
+        except KeyError:
+            raise DBTException(
+                'Invalid manifest.json - no nodes'
+            ) from None
+
         if 'length' in sequence_item:
             expected = self.get_fact(sequence_item['length'])
             assert expected == len(results)
@@ -301,12 +337,7 @@ class DbtItem(pytest.Item):
             extra_results_ok = sequence_item.get('extra_results_ok', False)
 
             for result in results:
-                try:
-                    name = result['node']['name']
-                except KeyError as exc:
-                    raise DBTException(
-                        f'Invalid result, missing required key {exc}'
-                    ) from None
+                name = self._get_name(result, nodes)
                 if (not extra_results_ok) and (name not in expected_names):
                     raise DBTException(
                         f'Got unexpected name {name} in results'
@@ -322,14 +353,7 @@ class DbtItem(pytest.Item):
             attributes = self._build_expected_attributes_dict(values)
 
             for result in results:
-                try:
-                    node = result['node']
-                    name = node['name']
-                except KeyError as exc:
-                    raise DBTException(
-                        f'Invalid result, missing required key {exc}'
-                    ) from None
-
+                name = self._get_name(result, nodes)
                 if name in attributes:
                     for key, value in attributes[name].items():
                         try:
@@ -509,7 +533,8 @@ class DbtItem(pytest.Item):
             schemas.add(relation.without_identifier())
         with self.adapter.connection_named('__test'):
             for schema in schemas:
-                found_relations.extend(self.adapter.list_relations_without_caching(schema))
+                found_relations.extend(
+                    self.adapter.list_relations_without_caching(schema))
 
         for key, value in expected.items():
             for relation in found_relations:
